package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````-9D$"#0```!(H@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(!)(`
M``22```%`````!````$```#(G@``R"X%",@N!0A@`@``S!(```8`````$```
M`@```-2>``#4+@4(U"X%""@!```H`0``!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&10@P``4`,%"%`#!0CL````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DR)X`
M`,@N!0C(+@4(.`$``#@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`N8\A06@JWSX0`FBE&]Y+&+&WYB\E````1`````@````(`````!P0!"5`
M!((X`4`!HH8!J,`!``)+*`0I.*(R1XH$#`A$````1@``````````````````
M`$@```!*````2P````````!,````30```$\```!0````40```%(`````````
M5```````````````50```%8```!9``````````````!:````7````%T```!?
M`````````&$```!C``````````````!E````9@```&<`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!?4&.Q</E/RSR
MV],=^J%L8+F-\0X`````````````````````%P,`````````````$@```+T#
M`````````````!(```!;`@`````````````2````#```````````````(```
M`%X$`````````````!(```"N`P`````````````2````U@$`````````````
M$@```#(#`````````````!(```"Q`0`````````````2````'@,`````````
M````$@```,L``````````````!(```#1`0`````````````2````U0(`````
M````````$@```&L#`````````````!(```#F`@`````````````2````\@$`
M````````````$@```'L#`````````````!(```!R`P`````````````2````
MHP$`````````````$@```+\!`````````````!(```#````````````````2
M````Y`$`````````````$@```*0"`````````````!(```!3`@``````````
M```2`````@,`````````````$@```!(!`````````````!(```#S`@``````
M```````2````'@$`````````````$@```.8``````````````!(```""`P``
M```````````2````*```````````````(````+8"`````````````!(```"/
M`P`````````````2````?@``````````````$@```!`#`````````````!(`
M``#$`P`````````````2````3`(`````````````$@```/8`````````````
M`!(```!)`0`````````````2````I```````````````$@```.T"````````
M`````!(```##`@`````````````2````=`(`````````````$@```/L"````
M`````````!(```!E```````````````2````V@``````````````$@```#D#
M`````````````!(```!S```````````````2````KP``````````````$@``
M`+8#`````````````!(````)`P`````````````2````7@$`````````````
M$@```#<``````````````"````"4`0`````````````2````VP$`````````
M````$@```)8#`````````````!(````D`P`````````````2````C0``````
M````````$@```$L``````````````"````"[`@`````````````2````6@,`
M````````````$@```&`"`````````````!(```!'`P`````````````2````
MA0(`````````````$@```,P"`````````````!(```!2`P`````````````2
M````H`,`````````````$@```"4!``"PE00(`````!(```#6!```",0$"`0`
M```1``\`C`0``*"S!`A0"P``$@`-`-T$``!@L`0(MP$``!(`#0`U!```],,$
M"``````2``X`V`,``$`Q!0@$````(0`9`#L$``!PK00(!0```!(`#0"\!```
MD,,$"%T````2``T`.`$``&"6!`@`````$@```(D!``!,,04(!````!$`&0"9
M!```&#$%"``````0`!@`9`,``$@Q!0@$````$0`9`)L$```8,04(`````"``
M&`#7`P``0#$%"`0````A`!D`*P0``/##!`@"````$@`-`,P$```D,04(!```
M`!$`&`#R!```@*T$"+P!```2``T`?`$``%`Q!0@!````$0`9`-8#``!`,04(
M!````!$`&0#1`P``0)<$"/4!```2``T`$04``""R!`A,````$@`-`$P$``!P
ML@0()````!(`#0!G!```H,($"'0````2``T`YP,``"@Q!0@`````$``9`/,#
M``"4004(`````!``&0"5`@``#,0$"`0````1``\`.P4``/"^!`BI`P``$@`-
M`*8$``"PK`0(L0```!(`#0"?!```-9D$"``````2``T`;`$``)"3!`@`````
M$@```(`$``!PKP0(Z````!(`#0#@`P``*#$%"``````0`!@`<P0``$"O!`@M
M````$@`-`!\%```@PP0(.````!(`#0#J!```,*P$""<````2``T``P$``%0Q
M!0@3````$0`9`/\$``"@L@0(^P```!(`#0#L!```W)($"``````2``L``&QI
M8G!E<FPN<V\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S
M=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!097)L7W-Y<U]T97)M`'!E<FQ?<&%R<V4`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7VYE=UA3`%!E<FQ?;F5W
M6%-?9FQA9W,`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!097)L7VUG7W-E
M=`!097)L7V=V7V9E=&-H<'8`4&5R;%]N97=35G!V`%!,7VUE;6]R>5]W<F%P
M`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A
M=&9O<FM?;&]C:P!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7V9E=&-H
M`&)O;W1?1'EN84QO861E<@!03%]D;U]U;F1U;7``4$Q?=&AR7VME>0!097)L
M7W-V7W-E='!V;@!097)L7W-V7W-E='!V`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`<&5R;%]F<F5E`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`
M<&5R;%]D97-T<G5C=`!L:6)N<VPN<V\N,0!L:6)D;"YS;RXR`&QI8FTN<V\N
M-@!L:6)C<GEP="YS;RXQ`&QI8G5T:6PN<V\N,0!L:6)P=&AR96%D+G-O+C``
M;W!E;C8T`&QS965K-C0`<F5A9`!P=&AR96%D7V=E='-P96-I9FEC`%]?97)R
M;F]?;&]C871I;VX`8VQO<V4`;&EB8RYS;RXV`%])3U]S=&1I;E]U<V5D`%]?
M<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I
M<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H
M<@!G971P:60`<W1R=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F
M7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M
M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V
M90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?
M961A=&$`7U]B<W-?<W1A<G0`7V5N9``O=7-R+VQI8B]P97)L-2\U+C(P+C$O
M:3,X-BUL:6YU>"UT:')E860M;75L=&DO0T]210!?7VQI8F-?8W-U7V9I;FD`
M<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP
M9&ER`%]?9&%T85]S=&%R=`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C
M7V-S=5]I;FET`&UY7W!A<E]P;`!?9G!?:'<`<&%R7VEN:71?96YV`'AS7VEN
M:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`%A37TEN=&5R;F%L<U]0
M05)?0D]/5`!'3$E"0U\R+C(`1TQ)0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#
M7S(N,RXR`$=,24)#7S(N-``````"``(``P````(``@`"``(````"```````$
M``(``@````(``@````````````4`!@`"`````@`"````!P````(``@````(`
M`@`&``````````(``@`#``(```````<```````(``@````````````@`!P``
M`````@`(``,`"``#``(``@`'`````0`!``$``0`"``$``0```````0`"``$`
M`@`!``$``0````(``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0``
M``$``0`!``(`/`(``!`````P````$FEI#0``!@!1!0``$````!!I:0T```,`
M6P4````````!``4`BP(``!``````````$FEI#0``"`!1!0``$````'09:0D`
M``<`904``!````!R&6D)```%`'$%```0````%&EI#0``!`!]!0``$````!!I
M:0T```(`6P4```````#\+P4(!A\``$`Q!0@%5@``2#$%"`5/``!,,04(!4T`
M`%`Q!0@%50``5#$%"`5G```,,`4(!P$``!`P!0@'`@``%#`%"`<#```8,`4(
M!P4``!PP!0@'!@``(#`%"`<'```D,`4(!P@``"@P!0@'"0``+#`%"`=A```P
M,`4(!PH``#0P!0@'"P``.#`%"`<,```\,`4(!PT``$`P!0@'#@``1#`%"`</
M``!(,`4(!Q```$PP!0@'$0``4#`%"`<2``!4,`4(!Q,``%@P!0@'%```7#`%
M"`<5``!@,`4(!Q8``&0P!0@'%P``:#`%"`<8``!L,`4(!QD``'`P!0@'&@``
M=#`%"`<;``!X,`4(!QP``'PP!0@''0``@#`%"`<>``"$,`4(!Q\``(@P!0@'
M(```C#`%"`<A``"0,`4(!R(``)0P!0@'(P``F#`%"`<D``"<,`4(!R4``*`P
M!0@')@``I#`%"`<G``"H,`4(!R@``*PP!0@'*0``L#`%"`<J``"T,`4(!T0`
M`+@P!0@'*P``O#`%"`<L``#`,`4(!RT``,0P!0@'+@``R#`%"`<O``#,,`4(
M!S```-`P!0@',0``U#`%"`<R``#8,`4(!S,``-PP!0@'-```X#`%"`=,``#D
M,`4(!S8``.@P!0@'-P``[#`%"`<X``#P,`4(!SD``/0P!0@'.@``^#`%"`<\
M``#\,`4(!ST````Q!0@'/@``!#$%"`<_```(,04(!T````PQ!0@'00``$#$%
M"`="```4,04(!T,``%.#[`CH>P8``('#&YT``(N#_/___X7`=`7H]@$``(/$
M"%O#`/\U!#`%"/\E"#`%"`````#_)0PP!0AH`````.G@_____R40,`4(:`@`
M``#IT/____\E%#`%"&@0````Z<#_____)1@P!0AH&````.FP_____R4<,`4(
M:"````#IH/____\E(#`%"&@H````Z9#_____)20P!0AH,````.F`_____R4H
M,`4(:#@```#I</____\E+#`%"&A`````Z6#_____)3`P!0AH2````.E0____
M_R4T,`4(:%````#I0/____\E.#`%"&A8````Z3#_____)3PP!0AH8````.D@
M_____R5`,`4(:&@```#I$/____\E1#`%"&AP````Z0#_____)4@P!0AH>```
M`.GP_O___R5,,`4(:(````#IX/[___\E4#`%"&B(````Z=#^____)50P!0AH
MD````.G`_O___R58,`4(:)@```#IL/[___\E7#`%"&B@````Z:#^____)6`P
M!0AHJ````.F0_O___R5D,`4(:+````#I@/[___\E:#`%"&BX````Z7#^____
M)6PP!0AHP````.E@_O___R5P,`4(:,@```#I4/[___\E=#`%"&C0````Z4#^
M____)7@P!0AHV````.DP_O___R5\,`4(:.````#I(/[___\E@#`%"&CH````
MZ1#^____)80P!0AH\````.D`_O___R6(,`4(:/@```#I\/W___\EC#`%"&@`
M`0``Z>#]____)9`P!0AH"`$``.G0_?___R64,`4(:!`!``#IP/W___\EF#`%
M"&@8`0``Z;#]____)9PP!0AH(`$``.F@_?___R6@,`4(:"@!``#ID/W___\E
MI#`%"&@P`0``Z8#]____):@P!0AH.`$``.EP_?___R6L,`4(:$`!``#I8/W_
M__\EL#`%"&A(`0``Z5#]____);0P!0AH4`$``.E`_?___R6X,`4(:%@!``#I
M,/W___\EO#`%"&A@`0``Z2#]____)<`P!0AH:`$``.D0_?___R7$,`4(:'`!
M``#I`/W___\ER#`%"&AX`0``Z?#\____)<PP!0AH@`$``.G@_/___R70,`4(
M:(@!``#IT/S___\EU#`%"&B0`0``Z<#\____)=@P!0AHF`$``.FP_/___R7<
M,`4(:*`!``#IH/S___\EX#`%"&BH`0``Z9#\____)>0P!0AHL`$``.F`_/__
M_R7H,`4(:+@!``#I</S___\E[#`%"&C``0``Z6#\____)?`P!0AHR`$``.E0
M_/___R7T,`4(:-`!``#I0/S___\E^#`%"&C8`0``Z3#\____)?PP!0AHX`$`
M`.D@_/___R4`,04(:.@!``#I$/S___\E!#$%"&CP`0``Z0#\____)0@Q!0AH
M^`$``.GP^____R4,,04(:``"``#IX/O___\E$#$%"&@(`@``Z=#[____)10Q
M!0AH$`(``.G`^___C4PD!(/D\/]Q_%6-00B)Y59348G+@^PP4(U!!%!1Z+W]
M__^#Q`QHL)4$"&BPE00(:&"6!`CHYBL``(/$$(`]4#$%"`!U,>C%_/__A<"C
MD$$%"`^$DP$``(/L#%#H#_S__UG_-4PQ!0CH,____X/$$,:`!04```"#[`S_
M-4PQ!0CH&____X"(M@(```):_S5,,04(Z`C___^`B+8"```!BP.#Q!#'1<P`
M````C5`%B57(WVW(V`5$`P4(W05(`P4(V<G:Z=_@G@^']0```(/L#,'B`E+H
MA_S__XMS!(L;@\00HX1!!0C'!8A!!0@$````BQ:#^P''0`3KQ00(QT`,[L4$
M"(D0BQ4D,04(B5`(N@$```!^$8UV`(L,EHE,D`R#P@$YVG7R@^P,QT28#```
M``"#PP-J`%!3:&"L!`C_-9!!!0CHB/W__X/$((7`B<-T18/L#/\UD$$%".AA
M^___C57DN*_$!`CHM`P``(/$$(7`=#B#[`S_-9!!!0CH__K__^@:_?__@\00
MC67TB=A96UY=C6'\PX/L#/\UD$$%".B<_?__@\00B</KIJ&,004(A<!T'X/L
M#%#HHRD``(/$$.NQ4%!H5#$%"&A?Q`0(Z%W\__^-5>2X9,0$".A`#```A<"C
MC$$%"'2*Z\F#[`QJ`>C+^___,>U>B>&#Y/!05%)H\,,$"&B0PP0(459H0)<$
M".CJ^___]&:09I!FD&:0D(L<),-FD&:09I!FD&:09I"X*S$%""TH,04(@_@&
M=AJX`````(7`=!%5B>6#[!1H*#$%"/_0@\00R?/#D(UT)@"X*#$%""TH,04(
MP?@"B<+!ZA\!T-'X=!NZ`````(72=!)5B>6#[!!0:"@Q!0C_TH/$$,GSPXUT
M)@"-O"<`````@#UG,04(`'4358GE@^P(Z'S____&!6<Q!0@!R?/#9I"XT"X%
M"(L0A=)U!>N3C78`N@````"%TG3R58GE@^P44/_2@\00R>EU____9I!FD)!5
M5XU('%93@>Q8`0``B40D"#'`D(UT)@"+%($/RHE4A!B#P`&#^!!U[XU4)$R-
MC"1,`0``C70F`(M"[#,"@\($,T+0,T+(T<")0@@YRG7IBT0D"(MP!(M0$(L8
MBT@,B?>+<`B)5"04`U0D&(G=B4PD!(M$)`2);"0,B30DB=Z)^\'&!??3C8PR
MF7F"6HG^BSPD(=B)\XET)!#!RP*)^B'R"="+5"0$`U0D'`'(B>GWT2'YB=:)
MZB':"<J-C!:9>8):BU0D((G&P<8%`?&)[@'ZB<W!S@*)U\'%!8VL+YEY@EJ)
MQ_?7B?J)Q\'(`B'W(=H#7"0D"?J)SP'JB<TAQ_?5P<D"(?4#="0H">^)U8V\
M.YEY@EK!Q06)ZP'[B=_!QP6-K#Z9>8):B=:)U_?6(<\AQ@G^B=\![@-$)"R)
MW<'*`O?5P<L"(<TAUP-,)#`)[XV\.)EY@EJ)\,'`!0''B?C!P`6-K`&9>8):
MB?&)\/?1(=@AT0-4)#0)P8GPB?X!Z8G]P<@"]]4AQL'/`B'=`UPD.`GNB<V-
MM#*9>8):P<4%`>Z)]<'%!8VL*YEY@EJ)R_?3B=J)R\')`B'[(<(#1"0\"=J)
M\P'JB?4AR_?5(?T)ZP-\)$#!S@*-G!B9>8):B=#!P`4!PXG8P<`%C:P'F7F"
M6HG0B=?WT"'WP<H"(<@#3"1$"?B)WP'HB=TAU_?5P<L"(?4#="1(">^-O#F9
M>8):B<'!P04!SXGYP<$%C:P.F7F"6HG!B<;WT2'>P<@"(=$#5"1,"?&)_@'I
MB?TAQO?5P<\"(=T#7"10">Z)S8VT,IEY@EK!Q04![HGUP<4%C:PKF7F"6HG+
M]].)VHG+P<D"(?LAP@-$)%0)VHGS`>J)]2'+]]7!S@(A_0-\)%@)ZXV<&)EY
M@EJ)T,'`!0'#B=C!P`6-K`>9>8):B=")U_?0(??!R@(AR`-,)%P)^(G?`>B)
MW2'7]]7!RP(A]0-T)&`)[XV\.9EY@EJ)P<'!!0'YB<_!QP6-K#Z9>8):B<:)
MQ_?6(=\AU@G^B<\![L'(`HG-`U0D9/?5(<<AW<')`@-<)&@)[XVL.IEY@EJ)
M]\''!0']B<\QQP-$)&R)^C'RP<X"C;P3H>O9;HGKB?+!PP4!WXGS,<L#3"1P
M,>O!S0*-M!BAZ]ENB?C!P`4!QHGH,=`#5"1T,?C!SP*-G`&AZ]ENB?'!P04!
MRXGY,>D#;"1XB<B)V3'PP<$%P<X"C90"H>O9;HG(B?$!T#'Y`WPD?(G*,=K!
MRP*-C!6AZ]ENB<7!Q04!Z8G=,?4#M"2`````B>J)S3'"P<4%P<@"C;P7H>O9
M;HGJ`?J)QS'?B=4#G"2$````,<_!Q07!R0*-O#ZAZ]ENB>X!_HG/,<>)]0.$
M)(@````QU\'%!<'*`HV\.Z'KV6Z)ZP'[B=<QSP.,)(P````Q]\'.`HV\.*'K
MV6Z)V,'`!0'XB?<QUS'?C;PYH>O9;HG!P<$%`?D#E"20````P<L"B=^)S3'W
MP<4%`[0DE````#''P<@"C;PZH>O9;HGJ`?J)QS'?B=4#G"28````,<_!Q07!
MR0*-O#ZAZ]ENB>X!_HG/,<>)]0.$))P````QU\'%!<'*`HV\.Z'KV6Z)ZP'[
MB=<QSP.,)*`````Q]\'.`HV\.*'KV6Z)V,'`!0'XB?<QUP.4)*0````QW\'+
M`HV\.:'KV6Z)P<'!!0'YB=\Q]XG-`[0DJ````#''P<4%P<@"C;PZH>O9;HGJ
M`?J)QS'?B=4#G"2L````,<_!Q07!R0*-O#ZAZ]ENB>X!_HG/,<>)]0.$)+``
M```QU\'%!<'*`HV\.Z'KV6Z)ZP'[B=<QSP.,)+0````Q]\'.`HV\.*'KV6Z)
MV,'`!0'XB?<QUP.4)+@````QW\'+`HV\.:'KV6Z)P8G=P<$%"?4!^8G?(<4A
M]PGOB<W!R`*-O#K<O!N/P<4%`[0DO````(GJB<4!^@G=B<<AS2'?P<D"">^)
MU0.<),````"-O#[<O!N/P<4%B>Z)S0'^"<6)SR'5(<?!R@()[XGU`X0DQ```
M`(V\.]R\&X_!Q06)ZXG5`?L)S8G7(?4AS\'.`@GO`XPDR````(GUC;PXW+P;
MCXG8"=7!P`4AW0'XB?<AUPGOC;PYW+P;CXG!P<$%P<L"`Y0DS````(G=`?F)
MWPGU(?<#M"30````(<7!R`()[XG-C;PZW+P;C\'%!8GJB<4!^@G=B<<AS2'?
MP<D"">^)U0.<)-0```"-O#[<O!N/P<4%B>Z)S0'^"<6)SR'5(<?!R@()[XGU
M`X0DV````(V\.]R\&X_!Q06)ZXG5`?L)S8G7(?4ASPGOC;PXW+P;CXG8P<`%
M`?C!S@(#C"3<````B?6)]PG5(=<#E"3@````(=W!RP()[XG=C;PYW+P;CXG!
M"?7!P04AQ<'(`@'YB=\A]P.T).0````)[XG-C;PZW+P;C\'%!8GJB<4!^@G=
MB<<AS2'?P<D"">^)U0.<).@```"-O#[<O!N/P<4%B>Z)S0'^"<6)SR'5(<<)
M[XGUC;P[W+P;C\'%!8GK`?O!R@(#A"3L````B=6)UPG-(<\#C"3P````(?7!
MS@()[XGUC;PXW+P;CXG8"=7!P`4AW<'+`@'XB?<AUP.4)/0````)[XG=C;PY
MW+P;CXG!"?7!P04AQ<'(`@'YB=\A]P.T)/@````)[XG-C;PZW+P;C\'%!8GJ
MB<4!^@G=B<<AS2'?P<D"">^)U8V\/MR\&X_!Q06)[HG-`?X#G"3\````B<\)
MQ2''`X0D``$``"'5P<H"">^)]8V\.]R\&X_!Q06)ZXG5`?L)S8G7(?4AS\'.
M`@GO`XPD!`$``(GUC;PXW+P;CXG8"=7!P`4AW<'+`@'XB?<AUP.4)`@!```)
M[XV\.=R\&X^)P<'!!0'/B=DQ\8G]`[0D#`$``#'!P<4%P<@"C8P*UL%BRHGJ
M`<J)P3'9,?F-M`[6P6+*B='!P07!SP(#G"00`0``B?T!\3'%`X0D%`$``(GN
MB<TQUL'%!8VT,];!8LJ)ZXG5P<T"`?.)[C']B>H#O"08`0``,<K!R0*-E!#6
MP6+*B=C!P`4!PHG(,?`#M"0<`0``B=4QV,'+`L'-`HV\!];!8LJ)T,'`!0''
MB=@QR`.,)"`!```QT(VT!M;!8LJ)^,'`!0'PB>XQW8GJB<4Q^L'%!<'/`HV,
M$=;!8LH!Z0.<)"0!``")_3'U`[0D*`$``(GJB<TQPL'%!<'(`HV<$];!8LJ)
MZ@':B<,Q^#'(`[PD+`$``,')`HVT!M;!8LJ)T,'`!0'&B<@QV`.<)#`!```Q
MT(V\!];!8LJ)\,'`!0'XB=?!SP*)_3'-`XPD-`$``(GJB<4Q\L'%!<'.`HV<
M$];!8LH!ZXGU,?T#O"0X`0``B>J)W3'"P<4%C8P1UL%BRHGJ`<J)P<')`HG(
M,?`QV(V\!];!8LJ)T,'`!<'+`@.T)#P!```!QXG8,<@#C"1``0``,=#!R@*-
MM`;6P6+*B=6)^#'=P<`%`YPD1`$```'PB>XQ_L'/`HVT,=;!8LJ)P<'!!0'.
MB?DQT0.4)$@!```QP<'(`HV<"];!8LJ)\8G%P<$%,?T#O"1,`0```=F)ZXG-
M,?/!S@+!Q06-G!K6P6+*B>J)]3'%`=J)ZXG5,<O!Q07!R0*-O!_6P6+*B>N+
M;"0,`?L#A"10`0``B<\#K"14`0``,?<QU\'*`HV\.-;!8LJ)V,'`!0'XC;PN
MUL%BRHG5,<V)[HG%`T0D$#'>P<4%P<L"`?Z+?"0(`>Z)1P2)-XLT)`-4)`0#
M3"04C00SB5<,B4<(B4\0@<18`0``6UY?7<-FD(7`#X2;````55=64X/L'(L-
M0#$%"(7)B4PD"'15#[8(@/D]=%N$R717B<.#PP$/M@N`^3UT!(3)=?$IPXM,
M)`B+*87M="R)5"0,B<:)SV:0@^P$4U95Z`7Q__^#Q!"%P'4'@'P=`#UT'X/'
M!(LOA>UUWH/$'#'`6UY?7<.-="8`,=OKN(UT)@")^BM4)`B+1"0,P?H"B1"#
MQ!R-1!T!6UY?7<,QP,.-=@"-O"<`````4XG#@^P8C50D#(G8Z#____^%P'0V
MC78`H4`Q!0B+5"0,C120BTH$A<F)"G39C78`@\($BTH$A<F)"G7TC50D#(G8
MZ`G___^%P'7-@\086\-55XG'5E,QP(G3@^PX@#H]#Y3``<-3Z+7N__^#Q!")
MQ8GXC50D'.C5_O__A<")Q@^$XP```(/L#%#HDN[__X/$$#G%#X:W````BT0D
M'(T,A0`````/M@<\/0^$;P$``(3`#X1G`0``B?CK"9"-="8`A-)T"X/``0^V
M$(#Z/77Q*?B-1"@"@^P,BS5`,04(4`'.Z,KM__^#Q!"%P(D&#X0^`0``H4`Q
M!0B+5"0<C4\!BQ20#[8'A,"(`G45ZQ>-=@"#P0$/MD'_@\(!A,"(`G0$/#UU
M[,8"/3'`C;0F``````^V#`.(3`(!@\`!A,EU\3'`@\0L6UY?7<.-M"8`````
M@\,!#[9#_X/&`83`B$;_=>_KW)"-="8`BQ5`,04(BP*%P`^$K0```#'VC;8`
M````@\8!BP2RA<!U]HT$M0@```"+#8!!!0B%R70U@^P(4%+H^^S__X/$$(7`
MHT`Q!0@/A'P```"-#+4`````QT2P!`````")="0<Z=?^__^-=@")5"0(@^P,
MQP6`004(`0```%#HR>S__X/$$(7`=$.-#+4`````@^P$48M4)!")3"044HE$
M)!10Z#3K__^+1"08@\00BTPD#*-`,04(ZYXQP.FL_O__N`@````Q]NE@____
MN/_____I!O___Y"-="8`A<!T!8`X`'4'PXVV`````%575E.)QH'LB````%#H
MKN[__X/$$(7`B<</A.4```"0@^P,5^@'[O__@\00A<")PP^$N@```(![$RX/
MA(@```"#[`R-:Q-6Z(3L__^)+"2)1"0<Z'CL__^+3"0<C40!`HD$).CXZ___
MB<-86E56:!#$!`AJ_VH!4^A3[O__@\0<C40D%%!3:@/HX^W__X/$$(/X_W00
MBT0D("4`\```/0!```!T:X/L#%/HXNK__X/$$(/L#%/H1NK__X/$$.E>____
MC;8`````#[9#%(3`#X1,____/"X/A63___^`>Q4`#X0Z____Z57___^0C70F
M`(/L#%?HM^W__XDT).@_ZO__@\00@\1\6UY?7<.-="8`B=CHV?[__^N8C;0F
M`````%93@^P0_S5,,04(Z%#M__^+0'Q;BW`$_S5,,04(Z#[M__\/MEAA6/\U
M3#$%"(/C?^@K[?__BT`$#[=`$,'@!PG#9HE>`EC_-4PQ!0CH#^W__XM`?(M8
M!%C_-4PQ!0CH_>S__X/$#&H`:.7%!`A0Z&WK__^)0QQ8_S5,,04(Z-[L__^+
M0'R+6`18_S5,,04(Z,SL__^+@+@#``")0R!8_S5,,04(Z+?L__^+0'Q:BU@$
M_S5,,04(Z*7L__^+B-@```"#Q!`QTH7)=!J#[`S_-4PQ!0CHB.S__XN`V```
M`(/$$(M0<(/L#(E3)/\U3#$%".AK[/__BT!\BT`$QT`H`````%C_-4PQ!0CH
M4NS__XM`?(M`!,=`&`````!:_S5,,04(Z#GL__^+0'Q9BU@$_S5,,04(Z"?L
M__^+@.0!``")0RR#Q!1;7L.0C;0F`````%.)PX/L%/\U3#$%".C_Z___C9#D
M````@\0,4E-J`^C]Z___@\00A<!T#H/$"#'`6\.-M"8`````@^P,_S5,,04(
MZ,KK__^+@/0```"#Q!`E`/```#T`0```=".#[`S_-4PQ!0CHI^O__XN`]```
M`(/$$"4`\```/0"@``!UK(/L"&H"4^C7ZO__@\00A<`/E,"#Q`@/ML!;PXVT
M)@````!55XG'5E.)U8'L(!```&6A%````(F$)!`0```QP&C_#P``C70D%%9H
M%L0$".A_Z/__@\00A<!^8(U8_X!\'`P`=$Z)PX/L!%-J+U;H$.K__X/$$(7`
M=$&#[`S_-4PQ!0CH"^O__U-65U#HDNK__X/$((N$)`P0``!E,P44````=36!
MQ!P0``!;7E]=PXUT)@"%VW6PC70F`(/L#/\U3#$%".C*ZO__@\0,55=0Z`_H
M__^#Q!#KN^BEY___D(UT)@"#[!C_-4PQ!0CHHNK__V@6Q@0(:)"3!`AH)<0$
M"%#H+>G__X/$+,.)]HV\)P````"#[!C_-4PQ!0CH<NK__XD$).BZ____6/\U
M3#$%".A>ZO__6EEJ`&CEQ00(:.7%!`AH\+X$"&A!Q`0(4.B`Z?__@\0LPXVV
M`````(V_`````%=64X'L$"```&6A%````(F$)`P@```QP.C#Y___@^P(:"'$
M!`A0:%;$!`AH`1```&H!C5PD)E/H1.K__X/$((7`>&6#[`1H`!```(V\)!,0
M``!74^@7Y___@\00A<")QGA&C4`!@^P,4.BBY___@\00A<")PW0Q@^P$5E=0
MZ#[F___&!#,`@\00B=B+E"0,(```93,5%````'41@<00(```6UY?PXUV`#'`
MZ]_H;^;__^L-D)"0D)"0D)"0D)"0D.D[____C70F`(V\)P````!55U93@>PL
M$```BYPD0!```(U4)!B+O"1$$```9:$4````B80D'!```#'`N&3$!`CHJ_?_
M_X/L"(G&:B]3Z$[G__^#Q!"%P'0MB=JX;<0$".B+^/__B=B+C"0<$```93,-
M%`````^%3`$``('$+!```%M>7UW#@^P,4^@QY___6EF)1"04:'K$!`A7Z##H
M__^#Q!")Q8M$)`R-?"0<@\`!B40D#(UT)@"%[72=@'T``'4%O6+$!`B%]G05
M@^P(55;HV^3__X/$$(7`#X2?````@^P,5>C7YO__@\00@'P%_R]U%)"-="8`
M@^@!@'P%_R_&1`4``'3QBTPD#(T4`8'Z_P\```^//____X/L!%-H?,0$"%5H
MH,4$"&@`$```:@%7Z(KH__^#Q!3_-4PQ!0CH+.C__X/$#`7D````4%=J`^@+
MZ/__@\00A<!U(X/L#/\U3#$%".@&Z/__BX#T````@\00)0#P```]`(```'09
M@^P(:'K$!`AJ`.A"Y___@\00B<7I(/___X/L"&H!5^@=Y___@\00A<!UU8GZ
MN&W$!`CH.O?__X/L#%?H<>;__X/$$.F@_O__Z)3D__^-="8`BT0D!`^V"(3)
M=""-4`'K"@^V"H/"`83)=!&`^2]U\0^V"HG0@\(!A,EU[_/#C78`4X/L&(M<
M)""%VW1<#[83A-)T58A4)`^#[`Q3Z*#E__^-1`/_@\00#[94)`\YPW(/ZRJ-
MM@````"#Z`$YV'0=@#@O=/3K#XUV`(V\)P````"`."]T0(/H`3G#<O0YPW4U
M@/HO=7*-=@"#[`QJ`NC>Y/__@\00A<!T5[HN````9HD0@\086\.-=@"-O"<`
M````@#@O=0>#Z`$YPW+T*=B-4`*!^@`0``!W)X/``6@`$```4%-H@#$%".C3
MY?__@\00N(`Q!0B#Q!A;PXVV`````(/$&#'`6\/'1"0@?,0$"(/$&%OI2.7_
M_Y"-M"8`````5U:#[#1EH10```")1"0L,<"A],4$"(E$)`JA^,4$"(E$)`ZA
M_,4$"(E$)!*A`,8$"(E$)!:A!,8$"(E$)!JA",8$"(E$)!ZA#,8$"(E$)"*A
M$,8$"(E$)"8/MP44Q@0(9HE$)"JX?L0$".A!]?__N(?$!`CH-_7__[B/Q`0(
MZ"WU__^XF,0$".@C]?__N)_$!`CH&?7__[BOQ`0(Z`_U__^X9,0$".@%]?__
MN+O$!`CH^_3__[C%Q`0(Z/'T__^XS\0$".CG]/__N&W$!`CHW?3__[C9Q`0(
MZ-/T__^XXL0$".C)]/__C50D!+CMQ`0(Z`OT__^%P'0,B<*XQ<0$".C[]/__
MC50D!+C^Q`0(Z.WS__^%P'0,B<*X$,4$".C=]/__C50D!+@;Q00(Z,_S__^%
MP'0SB<*X9,0$".B_]/__ND?%!`BXG\0$".BP]/__BT0D+&4S!10```!U58/$
M-%Y?PY"-="8`C50D!+@KQ00(Z(KS__^%P'06B<*XN\0$".AZ]/__Z[F0C;0F
M`````(UT)!N_/,4$"+D*````\Z9UGXU4)"6XN\0$".A0]/__ZX_HN>'__XGV
MC;PG`````*$@,04(@_C_=`;#D(UT)@"#[!RXN\0$"(U4)`SH'_/__X7`=",/
MMA"$T@^5P(#Z,`^5P@^VTB'0HR`Q!0B#Q!S#C;0F`````#'`Z^R-="8`@^P,
MZ&CA__^#[`Q0Z+_@__^#Q!"%P'0(BP"#Q`S#9I`QP.OVC;8`````C;\`````
M55>_4\4$"%93NTG%!`B#[#S'1"044\4$",=$)!A)Q00(C70D',=$)!Q6Q00(
MQT0D($S%!`C'1"0D4<4$",=$)"ACQ00(QT0D+`````#K(I"#[`C_="184.@3
MX/__@\00A<!T/(7;="Z+!HG?@\8$B<.-5"00B?CH1/+__X7`B<5T!8`X`'7)
MBU0D4(GXZ"[S__^%VW72@\0\6UY?7<-FD(/L#/]T)%SHY.'__XDL)(E$)!SH
MV.'__XM4)!R-1`("B00DZ%CA__^#Q`Q5:'K$!`C_="1<:*#%!`AJ_VH!4(E$
M)"SHJ./__X/$((M4)`R)^.C*\O__Z6G___^0C70F`%575E.![/R```"+A"00
M@0``C50D&,=$)!QZQ00(QT0D(&+$!`C'1"0D`````,=$)#00Q00(QT0D.`G%
M!`B)1"0(QT0D/'_%!`AEH10```")A"3L@```,<"X9,0$",=$)$`FQ00(QT0D
M1(?%!`C'1"1(`````,=$)"ANQ00(QT0D+(O%!`C'1"0P`````.@N\?__A<!T
M"8`X``^%Z0,``.@L_O__A<")PP^$^P,``(/L#%/HV>#__XU$``&#Q!"#[`Q0
MZ%G@__^#Q!"`.P")QHG'="F0C70F``^V`X/L#(/#`5!HE,4$"&K_:@%7@\<"
MZ)SB__^#Q""`.P!UW(U\)#BX$,4$".L3B?:-O"<`````@\<$BT?\A<!T-HU4
M)!CHG?#__X7`B<-TYX`X`'3BZ/WU__^%P'39@^P,4^C`X/__@\00A<")Q759
MC;0F`````(M<)!R%VW1(@#L`OP$```!U%NL\C70F`(M<O!R%VW0P@\<!@#L`
M="B)V.BQ]?__A<!TY8/L#%/H=.#__X/$$(7`=-6)Q>L+B?:-O"<`````,>V#
M[`R)\U7HX]___X/$$(L+@\,$C9'__O[^]]$ARH'B@("`@'3I]\*`@```=0;!
MZA"#PP(`TH/;`X/L#"GSC9P#!`0``%/H--___XE$)!16B<9HF<4$"&A\Q`0(
M56B>Q00(:O]J`5#H@^'__X/$*&C``0``5NC5W___@\00@_C_=&V#[`S_-4PQ
M!0CH#^'__X/$#`7D````4/]T)`QJ`^@+X?__@\00A<!T;(/L#/]T)!"+1"08
M_S!H7,8$"&H!_S5(,04(Z)7@__^#Q"`QP(N,).R```!E,PT4````#X7'"```
M@<3\@```6UY?7<.0Z(O?__^+`(/X$72'@^P(4/]T)!"+1"08_S!H(,8$".NM
MC;0F`````(/L#/\U3#$%".AZX/__BX#T````@\00)0#P```]`$````^%;?__
M_X/L#/\U3#$%".A3X/__B[#\````Z$C=__^#Q!`YQ@^%2?___X/L#/\U3#$%
M".@OX/__BX#T````@\00)?\!```]P`$```^%(O___X/L#%/H[=W__XU4)"B)
MQ;A,Q00(Z'WN__^#Q!"%P`^$V@<``(/L#%#HJ=[__UI94(M$)!3_,.A[]O__
M@\00A<")PP^$M@<``(/L#%/H%=[__X/$$(/X`WXMC70#_+^GQ00(N04```#S
MIG4;@_@$#X3G!0``@'P#^R\/A-P%``"-M"8`````Z,OZ__^%P'4:@^P(:@!3
MZ.S=__^)1"08@\00A<`/A24!``"Z1\4$"+B[Q`0(,=OHW.[__^@'W?__:.7%
M!`A0:'S$!`B+="005FC`Q00(:O]J`57HB-___X/$(.LWC78`Z`O>__^#.!%U
M0.C1W/__@\,!@^P,:.7%!`A34&A\Q`0(5FC.Q00(:O]J`57H3]___X/$,(/L
M"&C``0``5>B>W?__@\00@_C_=+:#[`S_="00Z%K;__^)ZKADQ`0(Z$[N__^)
M+"3HAOK__X/$$(GHZ>S]__^-="8`@^P,4(E$)!3H:_K__XM$)!2)!"3H7]W_
M_X/$$.G'_?__N&[%!`B^`0```.L.C78`BT2T*(/&`87`="F-5"08Z/3L__^%
MP'3H@#@`=..#[`Q0Z"+=__^#Q!"%P'33B</IPOO__[`-NW/%!`CIQOO__VH"
M:O]J[HMT)!16Z-C;__^#Q`QJ!HV$)/0```!05NAUVO__@\00@+PD[`````!U
M#H"\).T```!##X1D!0``:@!J`&H`_W0D%.B;V___QX0DG`````$C16?'A"2@
M````B:O-[\>$)*0```#^W+J8QX0DJ````'94,A#'A"2L````\.'2P\>$)+``
M````````QX0DM`````````#'A"3X`````````(/$$(EL)`R-="8`@^P$:`"`
M``"-A"3T````4/]T)!3HS]G__X/$$(7`B<8/CL$!``"+A"2@````C13P.=`/
MAZ`!``"+C"2D````B?")E"2@````P>@=`<B)A"2D````BX0DZ````(7`#X1E
M`0``ND````")]RG".=9^`HG7C80$J````(/L!%>-C"3T````45#HG=G__XN$
M)/@````!^(F$)/@```"#Q!"#^$`/A5G___^-A"3L````*?X!QXV$)(P```#H
M*N#__XUV`(V\)P````"#_C\/CM8```")]8G[C78`BP.#[4"#PT")A"2H````
MBT/$B80DK````(M#R(F$)+````"+0\R)A"2T````BT/0B80DN````(M#U(F$
M)+P```"+0]B)A"3`````BT/<B80DQ````(M#X(F$),@```"+0^2)A"3,````
MBT/HB80DT````(M#[(F$)-0```"+0_")A"38````BT/TB80DW````(M#^(F$
M).````"+0_R)A"3D````C80DC````.A?W___@_T_#X]&____@^Y`B?#!Z`:-
M4`'!X`8IQL'B!@'7:D165XV$)+0```!0Z.#9__^)M"3X````@\00Z3G^__^0
MC;PD[````.GT_O__C70F`(N$)*0```"-2`'I6/[__XML)`R#[`S_="04Z,';
M__^+G"2P````BY0DM````(G8P>@#@^`_C4@!QH0$N````("#Q!"#^3@/CP("
M``"Y-P```(VT!)T````IP8/Y!(U&#`^#.@(``(7)=`WVP0+&1@P`#X4\`P``
MB="(E"3C````B)PDYP```,'H&(U\)&.-="10B(0DX````(G0P>@0B(0DX0``
M`(G0P>@(B(0DX@```(G8P>@8B(0DY````(G8P>@0B(0DY0```(G8C9PDBP``
M`,'H"(B$).8```"-A"2,````Z"C>__^+E"2,````B=&(5"12P>D8#[;!B$PD
M3XG1P>D0B$PD4(G1BY0DD````,'I"(A,)%&)T8A4)%;!Z1B(3"13B='!Z1"(
M3"14B=&+E"24````P>D(B$PD58G1B%0D6L'I&(A,)%>)T<'I$(A,)%B)T8N4
M))@```#!Z0B(3"19B=&(5"1>P>D8B$PD6XG1P>D0B$PD7(G1BY0DG````,'I
M"(A,)%V)T8A4)&+!Z1B(3"1?B='!Z1"(3"1@B='!Z0B(3"1AZ0@```!FD`^V
M!H/&`8/L#%!HE,4$"&K_:@%7@\<"Z$3:__^#Q"`YWW7=QH0DBP````!HY<4$
M"(U$)&=0:'S$!`C_="00:+'%!`AJ_VH!5>@3VO__@\0@Z=7Z__^+1"0(BU`$
MA=(/A!SZ__^#[`Q2B50D&.COU___@\00@_@#BU0D"`^&__G__XUT`OR_K,4$
M"+D%````\Z8/A>GY__^)T^GB^?__N3\```"-M`2=````*<&#^02-1@QS>87)
M=`WVP0+&1@P`#X5*`0``C80DC````(VT)*@```")5"0(B??H@MS__[D.````
M,<"+5"0(\ZOIU_W__\=&#`````"#QA#'1`'\`````(/F_"GP`<B#X/R#^`0/
M@K+]__^#X/PQR<<$#@````"#P00YP7+RZ9K]___'1@P`````@\80QT0!_```
M``"#YOPI\`'(@^#\@_@$#X)S____@^#\,<G'!`X`````@\$$.<%R\NE;____
M@+PD[@```$$/A8[Z__^`O"3O````0P^%@/K__X"\)/````!(#X5R^O__@+PD
M\0```$4/A63Z__]J`FK_:L:+="045NC^U?__@\0,:BF-A"3T````4%;HF]3_
M_VCEQ00(C80D``$``%!H?,0$"/]T)"!HL<4$"&K_:@%5Z';8__^#Q##I./G_
M_XVV`````(M$)`B+&.D_^/__,?9FB70!_NFX_/__,?]FB7P!_NFJ_O__Z.#4
M__]55U93@^PH_S5,,04(Z-[7__^-5"0<QD!=`;B?Q`0(Z$SF__^#Q!"%P'0)
M@#@Q#X0\`@``Z#?Q__^#[`S_-4PQ!0CHJ=?__VH+:@%HW\4$"%#HBM7__X/$
M((7`#X2O````@SV(004(`8M`#(MX&`^.G````#'VNP$```#K+8UV`(M%#(/L
M"%"AA$$%"/\TF.B<T___@\00A<!U9:&(004(@\,!@\8!.=A^6X/L#/\U3#$%
M".@XU___:@!65U#HGM;__X/$((7`=#>+*(M%""4`!"``/0`$``!TIH/L#/\U
M3#$%".@(U___:@)J`%50Z%W4__^#Q"#KBY"-M"8`````H8A!!0B-4/\Y\@^$
M&`$``(/L#/\U3#$%".C2UO__:@-J`6CDQ00(4.BSU/__@\0@A<")PW0TBT`,
M@^P,BS#_-4PQ!0CHI];__X/$#&CFQ00(5E#HZ-/__XM##(/$$(L8]D,*0`^%
M``(``(/L#/\U3#$%".AXUO__:@-J`6CKQ`0(4.A9U/__@\0@A<")QG0YC50D
M#+AMQ`0(Z-+D__^%P(G##X18`0``BT8,@^P,BSC_-4PQ!0CH-=;__X/$#%-7
M4.AZT___@\00@^P,_S5,,04(Z!G6__^-5"0<QD!=`+ADQ`0(Z(?D__^#Q!"%
MP(G#HXQ!!0@/A(4```"#[`AHP`$``%#HE]3__XU0`8/$$(/Z`78)@_@1#X5Y
M`0``@\0<6UY?7<.-=@"#^`$/CM_^__^[`0```(UV`(V\)P````"#[`S_-4PQ
M!0B#PP'HG]7__UY=5U#H-M+__X/$$#D=B$$%"'_;Z:;^__^-M@````"`>`$`
M#X2__?__Z;7]__^0@^P,_S6$004(Z"+R__^#Q!"%P*.,004(#X3K````BT8,
MBSV$004(BQB+0P@E``0@`#T`!```#X6-````BT,,@^P(5U#H5]+__XG'BT8,
M@\00BQB+4PB!X@`$(`"!^@`$``!U1XM##%=0H81!!0C_,&C4Q@0(Z(;3__^-
MM@````"AA$$%"(/L#(LXBT8,BQC_-4PQ!0CHUM3__XGZB=CH7>G__X/$$.F>
M_O__@^P,_S5,,04(Z+?4__]J`FH`4U#H#-+__X/$(.N>@^P,_S5,,04(Z)G4
M__]J`FH`4U#H[M'__X/$(.E5____@^P,_S5,,04(Z'C4__]:65-0Z'_3__^#
MQ!#IX?W__X/L#&BPQ@0(Z.K2__]0H81!!0A3_S!H_,8$".C7TO__C;0F````
M`%93@^P0BW0D'%;HP>S__P^V"(/$$(G#A,ET((U0`>L*#[8*@\(!A,ET$8#Y
M+W7Q#[8*B=.#P@&$R77OZ$#O__^%P'0>A?9T&H`^`'05@^P(:)G%!`A3Z!70
M__^#Q!`YV'0&@\0$6U[#@\0$B?!;7ND\Y?__C;8`````C;\`````@^P8_S5,
M,04(Z++3__]:66K_4.@HT?__6/\U3#$%".B<T___@\0,:@!H@*D$"%#H7-/_
M_X/$',-FD&:09I!FD%/H^M7__X'#FFP``(/L"/^S'`$``/]T)!S_="0<_W0D
M'.CJT/__@\086\-FD&:0D%57,?]64^C%U?__@<-E;```@^P,BVPD((VSS/[_
M_^@IS___C8/(_O__*<;!_@*%]G0CC;8`````@^P$_W0D+/]T)"Q5_Y2[R/[_
M_X/'`8/$$#GW=>.#Q`Q;7E]=PXUV`//#``!3@^P(Z&/5__^!PP-L``"#Q`A;
MPP,````!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S
M`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"
M`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%2
M1U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]4
M35!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,
M14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42`!5
M4T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`<&%R
M+0`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE`"TM`````%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``!P97)L>'-I+F,`)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N
M<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I
M;VXI"@``56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z
M(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA
M;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E
M<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER
M("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN
M,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T
M;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I
M;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[
M(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G
M(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O
M;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L
M)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@
M/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D[
M"F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R
M;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B![
M"DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES
M=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*
M0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM0
M05)?05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@
M>PIF;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?
M05)'5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(
M*3L*;7D@)&)U9CL*<V5E:R!?1D@L("TX+"`R.PIR96%D(%]&2"P@)&)U9BP@
M.#L*;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["G-E96L@7T9(
M+"`M,3(L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+3$R("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T
M85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R
M8RD["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U
M9CL*8VQO<V4@)&]U=#L*8VAM;V0@,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%2
M7U1%35!]+R1B87-E;F%M921E>'0B.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*
M?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI
M<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@
M;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D
M*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D
M9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N
M<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*:68@*"1O=70I('L*8FEN;6]D92@D
M;W5T*3L*<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PIC;&]S92`D;W5T
M.PI]"F]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*8FEN;6]D
M92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II
M<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R
M(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H
M*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A
M<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`]
M(%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@
M;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES
M(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B
M.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/
M3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D
M(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<
M)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R
M(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA
M<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@
M(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC
M*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@
M/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@
M/#T^(&QE;F=T:"@D82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q
M(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@
M9F]R('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1?
M?2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO
M*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*
M;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I
M('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE
M(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN
M("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F
M:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E
M;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@
M)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@
M1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,
M12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C
M;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?
M=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P
M.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T
M>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F
M:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y0
M05(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET
M.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R
M;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@
M9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@
M<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P
M<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*
M?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?
M=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P
M.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF
M("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE
M('L*;7D@*"1E>'0L("1C<F,I(#T@0%\["FUY("@D9F@L("1F:6QE;F%M92D[
M"B1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["G5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE
M.PIP=7-H($!T;7!F:6QE+"`D9FEL96YA;64["GT*96QS92!["G)E='5R;B`H
M=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["GT*;W!E;B`D
M9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR
M971U<FXH)&9H+"`D9FEL96YA;64I.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D
M14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````````(#____/
M00$;`SOH````'````+"/__\$`0``\)/__^0-``#@EO__*`$``!"B__]H`0``
MP*+__\P!```0H___\`$```"E__]P`@``,*;__R0#``"`I___L`,``""H__\,
M!```X*C__Z@$```0J?__T`0``&"I__\(!0``(*K__Y0%```PJO__J`4``/"K
M__^D!@``(*S__[@&```0K?__&`<``-"N__](!P``(*___V0'``!0K___B`<`
M`%"P___T!P``H+O__]`+``!0O___8`T``-"___^L#0``$,#__R0.``!`P/__
M4`X``*#`__^<#@``%``````````!>E(``7P(`1L,!`2(`0``(````!P```"D
MCO__0`0````."$8.#$H/"W0$>``_&CLJ,B0B/````$````"PE?__+@L```!!
M#@B%`D$.#(<#1`X0A@1!#A2#!48.[`(#'`L.%$'##A!!Q@X,0<<."$'%#@0`
M`&````"`````H*#__Z8`````20X(A0)!#@R'`T$.$(8$00X4@P5##C`"1`XT
M00XX00X\00Y`2`XP5PH.%$/##A!!Q@X,0<<."$'%#@1%"UH.%$7##A!!Q@X,
M0<<."$'%#@0````@````Y````.R@__]0`````$$."(,"10X@`D@."$'##@0`
M``!\````"`$``!BA___K`0```$$."(4"00X,AP-##A"&!$$.%(,%1PY,20Y0
M2`Y`6@Y,00Y02`Y``D<.3$<.4$H.0`);"@X40<,.$$'&#@Q!QPX(0<4.!$@+
M`DX.2$$.3$$.4$@.0&\.3$L.4$@.0$X.1$$.2$D.3$4.4$P.0````+````"(
M`0``B*+__RD!````40X(A0)!#@R'`T$.$(8$00X4@P5(#IP!00Z@`4@.D`%.
M#IP!00Z@`4@.D`%7#IP!1`Z@`60.G`%!#I@!00Z<`4$.H`%%#J0!0@ZH`4(.
MK`%!#K`!2`Z4`44.F`%!#IP!0@Z@`4@.D`%8#IP!00Z@`4@.D`%##IP!00Z@
M`4@.D`%V#IP!00Z@`5`.D`%#"@X40<,.$$'&#@Q!QPX(0<4.!$4+`(@````\
M`@``!*/__T@!````00X(A@)!#@R#`T,.'$8.($D.'$D.($H.'$8.(%D.'$8.
M($P.'$8.($@.%$(.&$4.'$$.($D.'$8.($P.'$8.($\.'$8.($D.'$D.($X.
M$$D.'$8.($X.$$8.'$D.(%,.'$8.(%,.'$8.($D.'$D.(%$.#$'##@A!Q@X$
M6````,@"``#(H___F0````!!#@B#`D4.'$8.($X.%$$.&$$.'$(.($@.$$<*
M#@A#PPX$2`M##AQ&#B!.#A!/#AQ&#B!.#A!/#AA"#AQ!#B!(#A!(#@A$PPX$
M``"8````)`,```RD__^[`````$$."(4"00X,AP-##A"&!$$.%(,%2`ZT(%0.
MN"!%#KP@10[`($@.L"!3#K0@00ZX($(.O"!!#L`@2`ZP($<.O"!&#L`@1@[$
M($$.R"!!#LP@00[0($@.L"!6"@X40<,.$$'&#@Q!QPX(0<4.!$4+2PZ\($8.
MP"!(#K0@00ZX($$.O"!!#L`@2`ZP(``D````P`,``#"D__\G`````$,.'$8.
M($H.)$4.*$4.+$$.,$@.!```-````.@#```XI/__1`````!##AQ&#B!.#AQ&
M#B!&#AQ!#AA"#AQ%#B!%#B1%#BA%#BQ!#C!(#@2(````(`0``%"D__^Q````
M`$$."(<"00X,A@-!#A"#!$8.H$!7#JA`10ZL0$$.L$!%#K1`10ZX0$(.O$!%
M#L!`2`Z@0$<.I$!%#JA`2`ZL0$$.L$!(#J!`3`ZL0$$.L$!(#J!`20ZD0$$.
MJ$!!#JQ`00ZP0$P.H$!8"@X00<,.#$'&#@A!QPX$1`L``!````"L!```A*3_
M_P4`````````^````,`$``"`I/__O`$```!!#@B%`D$.#(<#00X0A@1!#A2#
M!48.P"!N#L@@1`[,($$.T"!(#L`@;`H.%$'##A!!Q@X,0<<."$'%#@1!"T,.
MS"!!#M`@1@[,($$.R"!)#LP@00[0($@.P"!K#L@@00[,($$.T"!(#L`@2P[,
M($$.T"!(#L`@<0[$($$.R"!%#LP@00[0($4.U"!%#M@@0@[<($$.X"!(#LP@
M1@[0($@.Q"!&#L@@00[,($(.T"!(#L`@1P[,($8.T"!.#L`@3P[(($4.S"!"
M#M`@2`[`($H.R"!"#LP@00[0($@.P"!3#LP@00[0($@.P"``$````+P%``!$
MI?__+0````````!<````T`4``&"E___H`````$$."(,"0PX@5@XL00XP3`X@
M`D0.+$(.,$@.($\*#@A!PPX$2PMA#B1!#BA!#BQ%#C!(#B!("@X(0<,.!$<+
M0PH."$/##@1!"TL."$'##@0L````,`8``/"E__^W`0```$$."(<"00X,A@-#
M#D`#6P$*#@Q!Q@X(0<<.!$8+```8````8`8``("G__],`````%,.(&T*#@1(
M"P``(````'P&``"TI___)`````!##A!(#AQ!#B!(#A!)"@X$0PL`:````*`&
M``#`I___^P````!!#@B%`D$.#(<#1@X0A@1!#A2#!4@.4`)"#EA$#EQ!#F!(
M#E!Y"@X40<,.$$'&#@Q!QPX(0<4.!$,+0PY<1`Y@9`Y400Y810Y<1`Y@10YD
M0@YH0@YL00YP3`Y0V`,```P'``!4J/__4`L```!!#@B%`D$.#(<#00X0A@1!
M#A2#!48.D(("`J<.G(("00Z@@@),#I""`D,.G(("00Z@@@)(#I""`E0.G(("
M1`Z@@@)%#J2"`D(.J(("0@ZL@@)!#K""`DL.D(("`D,.G(("00Z@@@)(#I""
M`@)##IR"`D$.H(("2`Z0@@)6#IR"`D,.H(("2`Z0@@)M#IR"`DH.H(("2@ZD
M@@)'#JB"`D4.K(("00ZP@@)%#K2"`D(.N(("0@Z\@@)!#L""`D@.F(("10Z<
M@@)!#J""`D@.D(("2`Z<@@)&#J""`D@.E(("1@Z8@@)$#IR"`D(.H(("2`Z0
M@@)'#IR"`D0.H(("1@ZD@@)%#JB"`D(.K(("1@ZP@@)(#I""`EP*#A1!PPX0
M0<8.#$''#@A!Q0X$0@M/"@Z8@@)!#IR"`D0.H(("1@ZD@@)%#JB"`DD+0PZ<
M@@)&#J""`DX.D(("4PZ<@@)&#J""`E,.D(("2PZ<@@)&#J""`DX.D(("4PZ<
M@@)!#J""`E@.D(("2PZ<@@)!#J""`D8.G(("00Z8@@)!#IR"`D8.H(("2`Z0
M@@)-#IR"`D$.H(("2`Z0@@)^#IB"`D(.G(("00Z@@@),#I""`F,.E(("00Z8
M@@)%#IR"`D4.H(("10ZD@@)"#JB"`D(.K(("00ZP@@)(#I""`EH.G(("10Z@
M@@)!#J2"`D$.J(("10ZL@@)!#K""`D4.M(("0@ZX@@)"#KR"`D$.P(("2`Z0
M@@)##IB"`D4.G(("00Z@@@)(#I""`D@.G(("1`Z@@@)<#I""`DX.G(("00Z@
M@@)8#I""`G0.G(("00Z@@@)(#I""`ED.E(("0@Z8@@)"#IR"`D4.H(("2`Z4
M@@)"#IB"`D@.G(("00Z@@@)(#I""`EH.E(("0@Z8@@)"#IR"`D0.H(("`F`.
MD(("2PZ4@@)%#IB"`D@.G(("1`Z@@@)(#I""`@)@#I2"`D$.F(("2`Z<@@)!
M#J""`E@.D(("`PL!#I2"`D$.F(("00Z<@@)(#J""`D\.D((";`Z<@@)$#J""
M`FD.D(("`W8!#IR"`D$.H(("10ZD@@)"#JB"`D(.K(("00ZP@@)+#I""`E$.
ME(("10Z8@@)%#IR"`D0.H(("10ZD@@)"#JB"`D(.K(("00ZP@@)(#I""`E<.
MG(("00Z@@@),#I""`@,P`0Z4@@)"#IB"`D(.G(("10Z@@@)(#I2"`D(.F(("
M2`Z<@@)!#J""`DH.I(("2`ZH@@)%#JR"`D0.L(("10ZT@@)"#KB"`D(.O(("
M00[`@@)(#I""`HP!``#H"@``R*___ZD#````00X(A0)!#@R'`T$.$(8$00X4
M@P5##CQ&#D!:#C!5#CQ&#D!'#D1"#DA%#DQ!#E!(#C!M#CA!#CQ(#D!(#C!6
M#CQ&#D!'#D1!#DA!#DQ!#E!(#C!8#CQ&#D!'#D1"#DA!#DQ!#E!(#C!=#CQ&
M#D!'#D1"#DA%#DQ!#E!(#C!,#CQ(#D!(#C1%#CA!#CQ!#D!+#C!/#CQ&#D!'
M#D1"#DA%#DQ!#E!(#C!D#CQ(#D!(#C1!#CA!#CQ!#D!(#C!##CQ&#D!:#C!2
M#CA%#CQ!#D!+#C!1"@X40<,.$$'&#@Q!QPX(0<4.!$0+6PX\1@Y`20X\00XX
M00X\00Y`2`XP9@X\1@Y`2`XP<0XX00X\00Y`30XP5PH.-$$..$<./$4.0$L+
M2`X\30Y`40XP2`X\1@Y`1PY$0@Y(00Y,00Y02`XP10X\1@Y`1PY$0@Y(00Y,
M00Y02`XP2`X\1@Y`1@X\00XX00X\00Y`2`XP2`H./$4.0$4+00XT1@XX0@X\
M10Y```!(````>`P``.BQ__]T`````$$."(8"00X,@P-##AQ%#B!+#A![#AA%
M#AQ!#B!(#A!'"@X,0<,."$'&#@1!"T,.#$/##@A!Q@X$````-````,0,```<
MLO__.`````!##AQ&#B!&#AQ!#AA"#AQ!#B!&#AQ&#B!(#A1"#AA%#AQ!#B!(
M#@0\````_`P```2&___U`0```$0,`0!*$`4"=0!%#P-U=`80!@)U?!`#`G5X
M`WP!"L$,`0!!PT'&0<5##`0$00L`*````#P-``#DL?__*P````!!#@B#`DX.
M$$8.%$0.&$0.'$0.($@."$'##@1(````:`T``.BQ__]=`````$$."(4"00X,
MAP-##A"&!$$.%(,%3@X@9PXD1`XH1`XL00XP30X@1PX40<,.$$'&#@Q!QPX(
M0<4.!```$````+0-``#\L?__`@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````":!`C@F00(``````$````!`````0`````"```!````
M#`(```$````7`@```0```"$"```!````+P(```$````\`@```0```(L"```/
M````^`,```P```#<D@0(#0```/3#!`@9````R"X%"!L````$````&@```,PN
M!0@<````!````/7^_V^L@00(!0```*B)!`@&````"(,$"`H```"'!0``"P``
M`!`````5``````````,`````,`4(`@```!@"```4````$0```!<```#$D`0(
M$0```)20!`@2````,````!,````(````_O__;P20!`C___]O`@```/#__V\P
MCP0(````````````````````````````````````````````````````````
M`````````````-0N!0@``````````!:3!`@FDP0(-I,$"$:3!`A6DP0(9I,$
M"':3!`B&DP0(EI,$"*:3!`BVDP0(QI,$"-:3!`CFDP0(]I,$"`:4!`@6E`0(
M)I0$"#:4!`A&E`0(5I0$"&:4!`AVE`0(AI0$"):4!`BFE`0(MI0$",:4!`C6
ME`0(YI0$"/:4!`@&E00(%I4$"":5!`@VE00(1I4$"%:5!`AFE00(=I4$"(:5
M!`B6E00(II4$"+:5!`C&E00(UI4$".:5!`CVE00(!I8$"!:6!`@FE@0(-I8$
M"$:6!`A6E@0(9I8$"':6!`B&E@0(EI8$"*:6!`BVE@0(QI8$"-:6!`CFE@0(
M]I8$"`:7!`@6EP0()I<$"#:7!`@``````````/____]`QP0(1T-#.B`H1TY5
M*2`T+CDN,B`R,#$T,3`P,2`H<')E<F5L96%S92D``"YS:'-T<G1A8@`N:6YT
M97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S
M:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R
M`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+FIC<@`N9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O
M;6UE;G0`````````````````````````````````````````````````````
M``````L````!`````@```%2!!`A4`0``$P```````````````0`````````3
M````!P````(```!H@00(:`$``"````````````````0`````````(0````<`
M```"````B($$"(@!```D```````````````$`````````#0```#V__]O`@``
M`*R!!`BL`0``7`$```4`````````!`````0````^````"P````(````(@P0(
M"`,``*`&```&`````0````0````0````1@````,````"````J(D$"*@)``"'
M!0`````````````!`````````$X```#___]O`@```#"/!`@P#P``U`````4`
M`````````@````(```!;````_O__;P(````$D`0(!!```)`````&`````@``
M``0`````````:@````D````"````E)`$")00```P````!0`````````$````
M"````',````)`````@```,20!`C$$```&`(```4````,````!`````@```!\
M`````0````8```#<D@0(W!(``",```````````````0`````````=P````$`
M```&`````),$"``3``!`!``````````````0````!````((````!````!@``
M`$"7!`A`%P``LBP`````````````$`````````"(`````0````8```#TPP0(
M]$,``!0```````````````0`````````C@````$````"````",0$"`A$``!(
M/P`````````````(`````````)8````!`````@```%`#!0A0@P``[```````
M````````!`````````"D`````0````(````\!`4(/(0``,@-````````````
M``0`````````K@````X````#````R"X%",B>```$```````````````$````
M`````+H````/`````P```,PN!0C,G@``!```````````````!`````````#&
M`````0````,```#0+@4(T)X```0```````````````0`````````RP````8`
M```#````U"X%"-2>```H`0``!@`````````$````"````-0````!`````P``
M`/PO!0C\GP``!```````````````!`````0```#9`````0````,`````,`4(
M`*```!@!``````````````0````$````X@````$````#````&#$%"!BA```0
M```````````````$`````````.@````(`````P```$`Q!0@HH0``5!``````
M````````0`````````#M`````0```#``````````**$``"<`````````````
M``$````!`````0````,``````````````$^A``#V```````````````!````
$````````
